/**
 * \file
 *
 * \brief Empty user application template
 *
 */

/**
 * \mainpage User Application template doxygen documentation
 *
 * \par Empty user application template
 *
 * This is a bare minimum user application template.
 *
 * For documentation of the board, go \ref group_common_boards "here" for a link
 * to the board-specific documentation.
 *
 * \par Content
 *
 * -# Include the ASF header files (through asf.h)
 * -# Minimal main function that starts with a call to system_init()
 * -# Basic usage of on-board LED and button
 * -# "Insert application code here" comment
 *
 */

/*
 * Include header files for all drivers that have been imported from
 * Atmel Software Framework (ASF).
 */
#include <asf.h>
#include <string.h>
#include "sio2host.h"
#include "dsp.h"
#include "data.h"

int main (void)
{
	system_init();
	system_set_sleepmode(SYSTEM_SLEEPMODE_STANDBY);
	sio2host_init();
	
	uint8_t					outBuf[APP_NUM_SAMPLES / 2];
	uint16_t				stepIndex;
	uint16_t				predictedValue;
	
	char					buffer[100];
	uint8_t					len;
	
	uint32_t				stop;
	uint32_t				delta;
	
	uint32_t				totalCycles = 0;
	
	stepIndex				= 0;
	predictedValue			= 0;
	
	for (int i = 0; i < 80; i++)
	{
		//	Start SysTick-teller
		SysTick->LOAD		= 0x00FFFFFF;
		SysTick->VAL		= 0;
		SysTick->CTRL		|= SysTick_CTRL_ENABLE_Msk;
		
		//	Prosesser data
		dsp_adpcm_ima_encode(outBuf, srcSamples, APP_NUM_SAMPLES, &stepIndex, &predictedValue);
		
		//	Stopp SysTick-teller
		SysTick->CTRL		&= ~(SysTick_CTRL_ENABLE_Msk);
		stop				= SysTick->VAL & SysTick_VAL_CURRENT_Msk;
		
		//	Tell klokkesykler
		delta				= 0x00FFFFFF - stop;
		totalCycles			+= delta;
	}
	
	//	Overfør antall klokkesykler via UART
	len = snprintf(buffer, 100, "Total:\t%d\r\n", totalCycles);
	sio2host_tx(buffer, len);
	
	//	Gå i dvale
	system_sleep();
}
