/*
 * main.c
 * 
 * Copyright 2014 Rune Bjønnum <rune@bjonnum.no>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 * 
 */
 
 //	Definitions
#define	DSP_ADPCM			true
#define APP_BUFFER_SIZE		524288

//	Includes
#include <stdio.h>
#include <windows.h>
#include "dsp.h"


//	Implementations
int main(int argc, char **argv)
{
	HANDLE					hInFile;
	HANDLE					hOutFile;
	uint8_t					*inBuf;
	uint8_t					*outBuf;
	uint32_t				outBufSize;
	DWORD					dwBytesRead;
	DWORD					dwBytesWritten;
	uint32_t				bytesToWrite;
	int16_t					stepIndex = 0;
	int16_t					predictedValue = 0;
	uint32_t				samplesTodo;
	
	//	Argument check
	if (argc != 4)
	{
		fprintf(stderr, "Usage: %s <e | d> <src file> <dst file>\n", argv[0]);
		ExitProcess(1);
	}
	
	if (*argv[1] != 'e' && *argv[1] != 'd')
	{
		fprintf(stderr, "Usage: %s <e | d> <src file> <dst file>\n", argv[0]);
		ExitProcess(1);
	}
	
	//	Try to open input file for reading
	if ((hInFile = CreateFile(argv[2], GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL)) == INVALID_HANDLE_VALUE)
	{
		fprintf(stderr, "%s: unable to open file '%s'\n", argv[0], argv[2]);
		ExitProcess(1);
	}
	
	//	Try to open output file for writing (overwrite if existing)
	if ((hOutFile = CreateFile(argv[3], GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ, NULL, CREATE_ALWAYS, 0, NULL)) == INVALID_HANDLE_VALUE)
	{
		fprintf(stderr, "%s: unable to open file '%s'\n", argv[0], argv[3]);
		ExitProcess(1);
	}
	
	//	Prepare buffers
	if ((inBuf = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, APP_BUFFER_SIZE)) == NULL)
	{
		fprintf(stderr, "%s: memory allocation error\n", argv[0]);
		ExitProcess(1);
	}
	
	switch (*argv[1])
	{
		case 'e':
			outBufSize = APP_BUFFER_SIZE / 4;
		break;
		
		case 'd':
			outBufSize = APP_BUFFER_SIZE * 4;
		break;
	}
	
	if ((outBuf = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, outBufSize)) == NULL)
	{
		fprintf(stderr, "%s: memory allocation error\n", argv[0]);
		ExitProcess(1);
	}
	
	//	File recode loop
	while(1)
	{
		if (!ReadFile(hInFile, inBuf, APP_BUFFER_SIZE, &dwBytesRead, NULL))
			break;
		
		if (dwBytesRead == 0)
			break;
		
		switch (*argv[1])
		{
			case 'e':
				samplesTodo = dwBytesRead / 2;
				dsp_adpcm_ima_encode(outBuf, (int16_t *) inBuf, samplesTodo, &stepIndex, &predictedValue);
				bytesToWrite = samplesTodo / 2;
			break;
			
			case 'd':
				samplesTodo = dwBytesRead * 2;
				dsp_adpcm_ima_decode((int16_t *) outBuf, inBuf, samplesTodo, &stepIndex, &predictedValue);
				bytesToWrite = samplesTodo * 2;
			break;
		}
		
		if (!WriteFile(hOutFile, outBuf, bytesToWrite, &dwBytesWritten, NULL))
		{
			fprintf(stderr, "%s: unable to write file '%s'\n", argv[0], argv[3]);
			ExitProcess(1);
		}
	}
	
	CloseHandle(hInFile);
	CloseHandle(hOutFile);
	HeapFree(GetProcessHeap(), 0, inBuf);
	HeapFree(GetProcessHeap(), 0, outBuf);
	
	return 0;
}

