/*
 * SerialDump.c
 * 
 * Copyright 2014 Rune Bjønnum <rune@bjonnum.no>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 * 
 */

//	Includes
#include <stdio.h>
#include <windows.h>

//	Definitions
#define SERIAL_BAUDRATE		115200

int main(int argc, char **argv)
{
	HANDLE					hFile;
	HANDLE					hSerial;
	DCB						dcbSerialParams;
	char					cDataIn;
	DWORD					dwBytesRead;
	DWORD					dwBytesWritten;
	char					newline = '\n';
	
	//	Argument check
	if (argc != 3)
	{
		fprintf(stderr, "Usage: %s <filename> <port>\n", argv[0]);
		ExitProcess(1);
	}
	
	//	Try to open file
	if ((hFile = CreateFile(argv[1], GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ, NULL, CREATE_ALWAYS, 0, NULL)) == INVALID_HANDLE_VALUE)
	{
		fprintf(stderr, "%s: unable to open file '%s'\n", argv[0], argv[1]);
		ExitProcess(1);
	}
	
	//	Try to open serial port
	if ((hSerial = CreateFile(argv[2], GENERIC_READ | GENERIC_WRITE, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL)) == INVALID_HANDLE_VALUE)
	{
		fprintf(stderr, "%s: unable to open port '%s'\n", argv[0], argv[2]);
		ExitProcess(1);
	}
	
	//	Set device parameters
	dcbSerialParams.DCBlength	= sizeof(dcbSerialParams);
	
	if (GetCommState(hSerial, &dcbSerialParams) == 0)
	{
		fprintf(stderr, "%s: unable to get device state\n", argv[0]);
		ExitProcess(1);
	}
	
	dcbSerialParams.BaudRate	= SERIAL_BAUDRATE;
	dcbSerialParams.ByteSize	= 8;
	dcbSerialParams.StopBits	= ONESTOPBIT;
	dcbSerialParams.Parity		= NOPARITY;
	
	if (SetCommState(hSerial, &dcbSerialParams) == 0)
	{
		fprintf(stderr, "%s: unable to set device parameters\n", argv[0]);
		ExitProcess(1);
	}
	
	if (!WriteFile(hSerial, &newline, 1, &dwBytesWritten, NULL))
	{
		fprintf(stderr, "%s: unable to write to port '%s'\n", argv[0], argv[2]);
		ExitProcess(1);
	}
	
	//	File transfer loop
	while (1)
	{
		if (!ReadFile(hSerial, &cDataIn, 1, &dwBytesRead, NULL))
		{
				fprintf(stderr, "%s: unable to read from port '%s'\n", argv[0], argv[2]);
				ExitProcess(1);
		}
		
		if (dwBytesRead == 1)
		{
			if (!WriteFile(hFile, &cDataIn, 1, &dwBytesWritten, NULL))
			{
				fprintf(stderr, "%s: unable to write to file '%s'\n", argv[0], argv[1]);
				ExitProcess(1);
			}
		}
	}
	
	return 0;
}

